summaryrefslogtreecommitdiff
path: root/include/comphelper/listenernotification.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-10-19 12:51:29 +0200
committerNoel Grandin <noelgrandin@gmail.com>2015-10-20 07:05:25 +0000
commit1b62841b1859ae3443e2bf1ebe99ec3d6afb6cc2 (patch)
treee3b7af8a34c55d7aad95752ad5d642a271523d08 /include/comphelper/listenernotification.hxx
parentb1659c95b0620cfd1291f889eae767757f696ae1 (diff)
com::sun::star->css in include/comphelper
Change-Id: Ice569b724732da1fd67a18a4ccf2f92f530cd689 Reviewed-on: https://gerrit.libreoffice.org/19459 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'include/comphelper/listenernotification.hxx')
-rw-r--r--include/comphelper/listenernotification.hxx40
1 files changed, 20 insertions, 20 deletions
diff --git a/include/comphelper/listenernotification.hxx b/include/comphelper/listenernotification.hxx
index b0603afbc722..65edfa5c36a1 100644
--- a/include/comphelper/listenernotification.hxx
+++ b/include/comphelper/listenernotification.hxx
@@ -65,9 +65,9 @@ namespace comphelper
You'll usually call this from within your own dispose/disposing method
*/
- void disposing( const ::com::sun::star::lang::EventObject& _rEventSource );
+ void disposing( const css::lang::EventObject& _rEventSource );
- /** clears the container without calling <member scope="com::sun::star::lang">XEventListener::disposing</member>
+ /** clears the container without calling <member scope="css::lang">XEventListener::disposing</member>
at the listeners
*/
void clear();
@@ -90,8 +90,8 @@ namespace comphelper
virtual ~OListenerContainer();
- void impl_addListener( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& _rxListener );
- void impl_removeListener( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& _rxListener );
+ void impl_addListener( const css::uno::Reference< css::lang::XEventListener >& _rxListener );
+ void impl_removeListener( const css::uno::Reference< css::lang::XEventListener >& _rxListener );
/** notifies all listeners of the given event, using THB's notification pattern
@@ -103,14 +103,14 @@ namespace comphelper
@see implNotify
*/
- bool impl_notify( const ::com::sun::star::lang::EventObject& _rEvent );
+ bool impl_notify( const css::lang::EventObject& _rEvent );
protected:
/** call a single listener
@pure
- @throws ::com::sun::star::uno::Exception
+ @throws css::uno::Exception
if the listener throws an exception during notification. Please don't catch
any listener exceptions in your implementation of this method, simply let them
pass to the caller.
@@ -129,8 +129,8 @@ namespace comphelper
@see notify
*/
virtual bool implNotify(
- const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& _rxListener,
- const ::com::sun::star::lang::EventObject& _rEvent
+ const css::uno::Reference< css::lang::XEventListener >& _rxListener,
+ const css::lang::EventObject& _rEvent
) = 0;
};
@@ -148,9 +148,9 @@ namespace comphelper
This class is not threadsafe!
@param LISTENER
- the listener class to call, e.g. com::sun::star::lang::XEventListener
+ the listener class to call, e.g. css::lang::XEventListener
@param EVENT
- the event type to notify, e.g. com::sun::star::lang::EventObject
+ the event type to notify, e.g. css::lang::EventObject
*/
template< class LISTENER, class EVENT >
class OSimpleListenerContainer : protected OListenerContainer
@@ -170,12 +170,12 @@ namespace comphelper
{
}
- inline void addListener( const ::com::sun::star::uno::Reference< ListenerClass >& _rxListener )
+ inline void addListener( const css::uno::Reference< ListenerClass >& _rxListener )
{
OListenerContainer::impl_addListener( _rxListener.get() );
}
- inline void removeListener( const ::com::sun::star::uno::Reference< ListenerClass >& _rxListener )
+ inline void removeListener( const css::uno::Reference< ListenerClass >& _rxListener )
{
OListenerContainer::impl_removeListener( _rxListener.get() );
}
@@ -191,8 +191,8 @@ namespace comphelper
protected:
virtual bool implNotify(
- const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& _rxListener,
- const ::com::sun::star::lang::EventObject& _rEvent
+ const css::uno::Reference< css::lang::XEventListener >& _rxListener,
+ const css::lang::EventObject& _rEvent
) override
{
const EventClass& rTypedEvent( static_cast< const EventClass& >( _rEvent ) );
@@ -229,12 +229,12 @@ namespace comphelper
{
}
- inline void addTypedListener( const ::com::sun::star::uno::Reference< ListenerClass >& _rxListener )
+ inline void addTypedListener( const css::uno::Reference< ListenerClass >& _rxListener )
{
OListenerContainer::impl_addListener( _rxListener.get() );
}
- inline void removeTypedListener( const ::com::sun::star::uno::Reference< ListenerClass >& _rxListener )
+ inline void removeTypedListener( const css::uno::Reference< ListenerClass >& _rxListener )
{
OListenerContainer::impl_removeListener( _rxListener.get() );
}
@@ -248,18 +248,18 @@ namespace comphelper
protected:
virtual bool implNotify(
- const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& _rxListener,
- const ::com::sun::star::lang::EventObject& _rEvent
+ const css::uno::Reference< css::lang::XEventListener >& _rxListener,
+ const css::lang::EventObject& _rEvent
) override
{
return implTypedNotify(
- ::com::sun::star::uno::Reference< ListenerClass >( static_cast< ListenerClass* >( _rxListener.get() ) ),
+ css::uno::Reference< ListenerClass >( static_cast< ListenerClass* >( _rxListener.get() ) ),
static_cast< const EventClass& >( _rEvent )
);
}
virtual bool implTypedNotify(
- const ::com::sun::star::uno::Reference< ListenerClass >& _rxListener,
+ const css::uno::Reference< ListenerClass >& _rxListener,
const EventClass& _rEvent
) = 0;
};